PALM-meteo: palmmeteo_stdplugins.write.WritePlugin Class Reference

PALM-meteo

Public Member Functions | List of all members
palmmeteo_stdplugins.write.WritePlugin Class Reference
Inheritance diagram for palmmeteo_stdplugins.write.WritePlugin:
[legend]
Collaboration diagram for palmmeteo_stdplugins.write.WritePlugin:
[legend]

## Public Member Functions
def | write_data (self, fout, *args, **kwargs)
def | write_data (self, *args, **kwargs)
Public Member Functions inherited from palmmeteo.plugins.Plugin
def | check_config (self, *args, **kwargs)
Public Member Functions inherited from palmmeteo.plugins.PluginMeta
def | __new__ (cls, name, bases, dct)

## Member Function Documentation

## ◆ write_data()

def palmmeteo_stdplugins.write.WritePlugin.write_data | ( |  | self,
|  |  | fout,
|  | * | args,
|  | ** | kwargs
| ) |  |

Reimplemented from palmmeteo.plugins.WritePluginMixin.

The documentation for this class was generated from the following file:

- palmmeteo_stdplugins/write.py